@@ -15,6 +15,7 @@ from pathlib import Path
 from pprint import pprint
 from urllib.parse import urlparse
 
+import certifi
 import configobj
 import qtoml
 import requests
@@ -26,9 +27,10 @@ def url_validator(url):
     try:
         result = urlparse(url)
         return True
-    except:
+    except BaseException:
         return False
 
+
 def fspath(path):
     """See https://www.python.org/dev/peps/pep-0519/#os for details."""
     if isinstance(path, (str, bytes)):
@@ -93,7 +95,7 @@ def post_json(url, payload, cookies):
         string: The json string.
     """
     try:
-        res = requests.post(url, data=payload, cookies=cookies, headers={"Content-Type":"application/json"})
+        res = requests.post(url, data=payload, cookies=cookies, headers={"Content-Type": "application/json"})
         if (res is None):
             return None
         if (res.status_code != 200):
@@ -151,6 +153,22 @@ def is_not_empty(my_string):
     return bool(my_string and my_string.strip())
 
 
+def sslcerts(dhurl, customcert):
+    try:
+        test = requests.get(dhurl)
+    except requests.exceptions.SSLError as err:
+        print('Adding custom certs to certifi store...')
+        cafile = certifi.where()
+        with open(customcert, 'rb') as infile:
+            customca = infile.read()
+        with open(cafile, 'rb') as infile:
+            ca = infile.read()
+        with open('/tmp/customca.pem', 'ab') as outfile:
+            outfile.write(ca)
+            outfile.write(customca)
+        os.environ['SSL_CERT_FILE'] = '/tmp/customca.pem'
+
+
 def login(dhurl, user, password, errors):
     """
     Login to DeployHub using the DH Url, userid and password.
@@ -647,10 +665,11 @@ def get_previous_commit(dhurl, cookies, compname):
     data = get_component(dhurl, cookies, compname, "", "", True, True)
     parent_compid = data[0]
     if (parent_compid > 0):
-     data = get_component_fromid(dhurl, cookies, parent_compid)
-     if (data.get('result', None) is not None):
-        return data['result'].get('gitcommit', '')
-    return ''   
+        data = get_component_fromid(dhurl, cookies, parent_compid)
+        if (data.get('result', None) is not None):
+            return data['result'].get('gitcommit', '')
+    return ''
+
 
 def get_component_attrs(dhurl, cookies, compid):
     """
@@ -954,7 +973,7 @@ def new_component_item(dhurl, cookies, compid, kind, component_items):
                 parent_item = data['result']['id']
 
             ypos = ypos + 100
-            i = i+1
+            i = i + 1
     return data
 
 
@@ -1115,6 +1134,7 @@ def update_envid_attrs(dhurl, cookies, envid, attrs):
         return [False, "Could not update attributes on '" + str(envid) + "'"]
     return [True, data, dhurl + "/dmadminweb/API/setvar/environment/" + str(envid)]
 
+
 def is_compassigned2app(dhurl, cookies, appid, compid):
     """
     Check to see if the component is already assigned to the application version.
@@ -1133,7 +1153,7 @@ def is_compassigned2app(dhurl, cookies, appid, compid):
 
     if (data is None):
         return False
-        
+
     return data.get('result', False)
 
 
@@ -1254,6 +1274,7 @@ def get_base_component(dhurl, cookies, compid, id_only):
 
     return result['id']
 
+
 def get_component_from_tag(dhurl, cookies, image_tag):
     """
     Get the component based on the docker tag.
@@ -1359,7 +1380,7 @@ def new_application(dhurl, cookies, appname, appversion, appautoinc, envs, compi
 
     if (compassigned2app):
         return[latest_appid, ".".join(parts) + "." + latest_name]
-    
+
     if (appid < 0):
         data = get_json(dhurl + "/dmadminweb/API/newappver/" + str(latest_appid) + "/?name=" + urllib.parse.quote(appname + ";" + appversion) + "&" + domain, cookies)
 
@@ -1547,7 +1568,7 @@ def import_cluster(dhurl, cookies, domain, appname, appversion, appautoinc, depl
                 compversion = tag
 
                 if (full_msname == msname):
-                    deployed_ms = {'compid' : compid, 'compname': compname, 'compvariant': compvariant, 'compversion': compversion, 'full_msname': full_msname, 'msname': short_msname, 'branch': branch, 'repo': repo, 'tag': tag, 'deploy_time': deploy_time}
+                    deployed_ms = {'compid': compid, 'compname': compname, 'compvariant': compvariant, 'compversion': compversion, 'full_msname': full_msname, 'msname': short_msname, 'branch': branch, 'repo': repo, 'tag': tag, 'deploy_time': deploy_time}
 
                 if (branch in ('master', 'main')):
                     if (not msversion.startswith('1.') and msversion != "1"):
@@ -1555,11 +1576,11 @@ def import_cluster(dhurl, cookies, domain, appname, appversion, appautoinc, depl
 
                     latest_container = master_containers.get(short_msname, None)
                     if (latest_container is None):
-                        master_containers[short_msname] = {'compid' : compid, 'compname': compname, 'compvariant': compvariant, 'compversion': compversion, 'full_msname': full_msname, 'msname': short_msname, 'branch': branch, 'repo': repo, 'tag': tag, 'deploy_time': deploy_time}
+                        master_containers[short_msname] = {'compid': compid, 'compname': compname, 'compvariant': compvariant, 'compversion': compversion, 'full_msname': full_msname, 'msname': short_msname, 'branch': branch, 'repo': repo, 'tag': tag, 'deploy_time': deploy_time}
                     elif (latest_container['deploy_time'] <= deploy_time):
-                        master_containers[short_msname] = {'compid' : compid, 'compname': compname, 'compvariant': compvariant, 'compversion': compversion, 'full_msname': full_msname, 'msname': short_msname, 'branch': branch, 'repo': repo, 'tag': tag, 'deploy_time': deploy_time}
+                        master_containers[short_msname] = {'compid': compid, 'compname': compname, 'compvariant': compvariant, 'compversion': compversion, 'full_msname': full_msname, 'msname': short_msname, 'branch': branch, 'repo': repo, 'tag': tag, 'deploy_time': deploy_time}
                 elif (msbranch is not None and branch == msbranch):
-                    branch_containers.append({'compid' : compid, 'compname': compname, 'compvariant': compvariant, 'compversion': compversion, 'full_msname': full_msname, 'msname': short_msname, 'branch': branch, 'repo': repo, 'tag': tag, 'deploy_time': deploy_time})
+                    branch_containers.append({'compid': compid, 'compname': compname, 'compvariant': compvariant, 'compversion': compversion, 'full_msname': full_msname, 'msname': short_msname, 'branch': branch, 'repo': repo, 'tag': tag, 'deploy_time': deploy_time})
 
         if (msbranch is not None):
             complist = []
@@ -1611,7 +1632,6 @@ def import_cluster(dhurl, cookies, domain, appname, appversion, appautoinc, depl
             for item in compid_list:
                 new_ids.append(item['compid'])
 
-
             if (areEqual(existing_ids, new_ids)):
                 print("Application Version " + appname + ";" + appversion + " already exists")
             else:
@@ -1640,6 +1660,7 @@ def import_cluster(dhurl, cookies, domain, appname, appversion, appautoinc, depl
             log_deploy_application(dhurl, cookies, deploydata)
     return
 
+
 def areEqual(arr1, arr2):
     n = len(arr1)
     m = len(arr2)
@@ -1661,6 +1682,7 @@ def areEqual(arr1, arr2):
     # If all elements were same.
     return True
 
+
 def log_deploy_application(dhurl, cookies, deploydata):
     """
     Record a deployment of an application to an environment.
@@ -1722,9 +1744,11 @@ def run_circleci_pipeline(pipeline):
     data = post_json_with_header(url, os.environ.get("CI_TOKEN", ""))
     return data
 
+
 def get_script_path():
     return os.path.dirname(os.path.realpath(sys.argv[0]))
 
+
 def upload_helm(dhurl, cookies, fullcompname, chart, chartversion, chartvalues, helmrepo, helmrepouser, helmrepopass, helmrepourl, helmopts, deployid, dockeruser, dockerpass, helmtemplate):
     """
     Gather the helm chart and values and upload to the deployment log
@@ -1857,6 +1881,7 @@ def upload_helm(dhurl, cookies, fullcompname, chart, chartversion, chartvalues,
     # pprint(data)
     print("Finished Helm Capture for Deployment #" + str(deployid))
 
+
 def set_kvconfig(dhurl, cookies, kvconfig, appname, appversion, appautoinc, compname, compvariant, compversion, compautoinc, kind, env, crdatasource, crlist):
     """
     Update the attributes for the component based on the properties files found in the cloned directory.
@@ -1936,7 +1961,7 @@ def set_kvconfig(dhurl, cookies, kvconfig, appname, appversion, appautoinc, comp
         try:
             print(filename)
             config = ConfigObj(filename, encoding='iso-8859-1')
-            filename = filename[len(kvconfig)+1:]
+            filename = filename[len(kvconfig) + 1:]
             normal_dict[filename] = config.dict()
         except configobj.ConfigObjError as error:
             print(error)
@@ -2053,6 +2078,7 @@ def set_kvconfig(dhurl, cookies, kvconfig, appname, appversion, appautoinc, comp
             update_envid_attrs(dhurl, cookies, envid, attrs)
     return
 
+
 def post_textfile(dhurl, cookies, compid, filename, file_type):
 
     file_data = ''
@@ -2064,7 +2090,10 @@ def post_textfile(dhurl, cookies, compid, filename, file_type):
             if (res.status_code == 200):
                 file_data = res.content
         except requests.exceptions.ConnectionError as conn_error:
-            print(str(conn_error))
+            print("WARNING: " + filename + " not found")
+
+    if (is_empty(file_data)):
+      return
 
     encoded_bytes = base64.encodebytes(file_data)
 
@@ -2076,15 +2105,16 @@ def post_textfile(dhurl, cookies, compid, filename, file_type):
         file.append(d)
 
     payload = {'compid': compid, 'filetype': file_type, 'file': file}
-    result = post_json(dhurl+"/msapi/textfile/", json.dumps(payload), cookies)
+    result = post_json(dhurl + "/msapi/textfile/", json.dumps(payload), cookies)
 
     if (result is None):
         return ({"message": "Could not persist '" + filename + "' with compid: '" + str(compid) + "'"})
     return result
 
+
 def update_deppkgs(dhurl, cookies, compid, filename):
     payload = ""
-    
+
     parts = filename.split('@')
     filetype = parts[0].lower()
     filename = parts[1]
@@ -2093,12 +2123,13 @@ def update_deppkgs(dhurl, cookies, compid, filename):
         data = json.load(fin_data)
         payload = json.dumps(data)
 
-    result = post_json(dhurl+"/msapi/deppkg/" + filetype + "?compid=" + str(compid), payload, cookies)
+    result = post_json(dhurl + "/msapi/deppkg/" + filetype + "?compid=" + str(compid), payload, cookies)
 
     if (result is None):
         return ({"message": "Could not persist '" + filename + "' with compid: '" + str(compid) + "'"})
     return result
 
+
 def run_git(cmd):
     pid = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
     retval = ""
